==> metocean_stats-1.0.3.tar.gz: metocean_stats-1.0.3/README.md <==
<h1>
  met<img src="https://github.com/MET-OM/metocean-stats/blob/main/docs/files/logo.png" width="20" height="20" />cean-stats
 </h1>

[![Tests (python)](https://github.com/MET-OM/metocean-stats/actions/workflows/tests.yml/badge.svg)](https://github.com/MET-OM/metocean-stats/actions/workflows/tests.yml)
[![Documentation Status](https://readthedocs.org/projects/metocean-stats/badge/?version=latest)](https://metocean-stats.readthedocs.io/en/latest/?badge=latest)	[![Documentation Status](https://readthedocs.org/projects/metocean-stats/badge/?version=latest)](https://metocean-stats.readthedocs.io/en/latest/?badge=latest)

## Purpose 🎯
Metocean-stats is a tool for comprehensive statistics and visualization of metocean data (wind, waves, ocean currents, tide levels, air and water temperature, sea ice, and more). The tool is also compatible with WEkEO Jupyter Lab, allowing seamless integration and use.

![metocean-stats](https://github.com/MET-OM/metocean-stats/blob/main/docs/files/readme_plots.png)

⚠️ Please note that while metocean-stats is designed to provide accurate statistics and visualizations of metocean data, the user is ultimately responsible for correctly using the tool and interpreting the results. The tool is not liable for any errors or actions taken based on the information provided by the tool. Users should cross-verify the results and use them with discretion.

## Quick Installation 💻

To get started with metocean-stats, you can install it with pip or conda:

```shell
$ pip install metocean-stats 
```

or

```shell
$ conda install conda-forge::metocean-stats
```

## Docs 📚
Looking for more details? Our documentation (under development) provides information about the package, its features, and how to use it. Check it out [here](https://metocean-stats.readthedocs.io/en/latest/index.html).

Let's dive into the world of metocean data! 🌊🏄‍♀️

<img src="https://github.com/MET-OM/metocean-stats/blob/main/docs/files/animation.gif" width="400" height="400" />

==> metocean_stats-1.0.5.tar.gz: metocean_stats-1.0.5/README.md <==
<h1>
  met<img src="https://github.com/MET-OM/metocean-stats/blob/main/docs/files/logo.png" width="20" height="20" />cean-stats
 </h1>

[![Tests (python)](https://github.com/MET-OM/metocean-stats/actions/workflows/tests.yml/badge.svg)](https://github.com/MET-OM/metocean-stats/actions/workflows/tests.yml)
[![Documentation Status](https://readthedocs.org/projects/metocean-stats/badge/?version=latest)](https://metocean-stats.readthedocs.io/en/latest/?badge=latest)

## Purpose 🎯
Metocean-stats is a tool for comprehensive statistics and visualization of metocean data (wind, waves, ocean currents, tide levels, air and water temperature, sea ice, and more). The tool is also compatible with WEkEO Jupyter Lab, allowing seamless integration and use. For instructions on how to install metocean-stats in WEkEO, please refer [here](https://docs.google.com/document/d/1uEvG_YZ43eu3vE33Qv9t5Bzd0QAmspKjqjzFLHEkJys/edit?usp=sharing).

![metocean-stats](https://github.com/MET-OM/metocean-stats/blob/main/docs/files/readme_plots.png)

⚠️ Please note that while metocean-stats is designed to provide accurate statistics and visualizations of metocean data, the user is ultimately responsible for correctly using the tool and interpreting the results. The tool is not liable for any errors or actions taken based on the information provided by the tool. Users should cross-verify the results and use them with discretion.

## Quick Installation 💻

To get started with metocean-stats, you can install it with pip or conda:

```shell
$ pip install metocean-stats 
```

or

```shell
$ conda install conda-forge::metocean-stats
```

## Docs 📚
Looking for more details? Our documentation (under development) provides information about the package, its features, and how to use it. Check it out [here](https://metocean-stats.readthedocs.io/en/latest/index.html).

Let's dive into the world of metocean data! 🌊🏄‍♀️

<img src="https://github.com/MET-OM/metocean-stats/blob/main/docs/files/animation.gif" width="400" height="400" />
